@@ -7,9 +7,9 @@
 #ifndef DEBUGGER_H
 #define DEBUGGER_H
 
-#include <ntqtimer.h>
-#include <ntqdict.h>
-#include <ntqstringlist.h>
+#include <tqtimer.h>
+#include <tqdict.h>
+#include <tqstringlist.h>
 #include "envvar.h"
 #include "exprwnd.h"			/* some compilers require this */
 
