@@ -8,8 +8,8 @@
 #define PgmArgs_included
 
 #include "pgmargsbase.h"
-#include <ntqlineedit.h>
-#include <ntqdict.h>
+#include <tqlineedit.h>
+#include <tqdict.h>
 #include "envvar.h"
 
 class TQStringList;
