@@ -7,7 +7,7 @@
 #ifndef REGWND_H
 #define REGWND_H
 
-#include <ntqlistview.h>
+#include <tqlistview.h>
 #include <list>
 #include <map>
 
