@@ -7,8 +7,8 @@
 #ifndef THREADLIST_H
 #define THREADLIST_H
 
-#include <ntqlistview.h>
-#include <ntqpixmap.h>
+#include <tqlistview.h>
+#include <tqpixmap.h>
 #include <list>
 
 class ThreadInfo;
